@@ -1,4 +1,4 @@
-/*  $Id: Command.h,v 1.22 2012/11/18 19:56:04 sarrazip Exp $
+/*  $Id: Command.h,v 1.24 2016/11/20 07:26:34 sarrazip Exp $
     Command.h - Abstract command-line driver
 
     verbiste - French conjugation system
@@ -30,6 +30,8 @@
 #include <verbiste/FrenchVerbDictionary.h>
 
 #include <string>
+#include <stdlib.h>
+#include <errno.h>
 
 
 namespace verbiste {
@@ -68,10 +70,8 @@ public:
     /** Use the given arguments as verbs, or stdin if no arguments are given.
         If arguments are given, argv[0] must be the first argument, and not
         the name of the current program.
-        The verbs are expected to be in Latin-1 (ISO-8859-1).
-        They are converted to lower-case
-        and passed to the processInputWord() method, which must be overridden
-        by a class derived from this one.
+        They are converted to lower-case and passed to the processInputWord()
+        method, which must be overridden by a class derived from this one.
     */
     int run(int argc, char *argv[]) throw();
 
