@@ -1,4 +1,4 @@
-/*  $Id: french-conjugator.cpp,v 1.31 2012/11/18 19:56:04 sarrazip Exp $
+/*  $Id: french-conjugator.cpp,v 1.33 2016/11/20 07:26:34 sarrazip Exp $
     french-conjugator.cpp - Conjugation of French verbs
 
     verbiste - French conjugation system
@@ -39,6 +39,7 @@
 
 #include <iostream>
 #include <vector>
+#include <algorithm>
 #include <string.h>
 
 using namespace std;
@@ -59,6 +60,7 @@ static struct option knownOptions[] =
     { "template",       required_argument,      NULL, 'e' },
     { "pronouns",       no_argument,            NULL, 'p' },
     { "all-infinitives",no_argument,            NULL, 'i' },
+    { "data-dir",       required_argument,      NULL, 'd' },
 
     { NULL, 0, NULL, 0 }  // marks the end
 };
@@ -73,12 +75,14 @@ public:
                       const string &verbsFilename,
                       FrenchVerbDictionary::Language lang) throw(logic_error)
       : Command(conjugationFilename, verbsFilename, lang),
-        reqMode(INVALID_MODE),
-        reqTense(INVALID_TENSE),
+        reqModes(),
+        reqTenses(),
         reqTemplate(),
         includePronouns(false),
         aspirateH(false)
     {
+        reqModes.reserve(8);
+        reqTenses.reserve(8);
     }
 
     virtual ~ConjugatorCommand()
@@ -86,8 +90,8 @@ public:
     }
 
     // Constraints:
-    Mode reqMode;
-    Tense reqTense;
+    vector<Mode>  reqModes;   // empty means all
+    vector<Tense> reqTenses;  // empty means all
     string reqTemplate;
     bool includePronouns;
 
@@ -112,6 +116,16 @@ private:
 };
 
 
+template <typename ElementType>
+static bool
+applyConstraint(const vector<ElementType> &v, ElementType candidateValue)
+{
+    if (v.empty())
+        return true;  // no constraint, so always accept
+    return find(v.begin(), v.end(), candidateValue) != v.end();
+}
+
+
 void
 ConjugatorCommand::displayTense(FrenchVerbDictionary &fvd,
                                 const string &radical,
@@ -119,9 +133,9 @@ ConjugatorCommand::displayTense(FrenchVerbDictionary &fvd,
                                 Mode mode,
                                 Tense tense)
 {
-    if (reqMode != INVALID_MODE && mode != reqMode)
+    if (!applyConstraint(reqModes, mode))
         return;
-    if (reqTense != INVALID_TENSE && tense != reqTense)
+    if (!applyConstraint(reqTenses, tense))
         return;
 
     cout << "- " << FrenchVerbDictionary::getModeName(mode)
@@ -281,11 +295,15 @@ displayHelp()
 "--version          Display this program's version number and exit\n"
 "--lang=L           Select language L (fr for French, it for Italian)\n"
 "                   Default is French.\n"
-"--mode=M           Only display mode M (infinitive, indicative, etc)\n"
+"--mode=M           Only display mode M (infinitive, indicative, etc.)\n"
+"                   (M can also be a comma-separated list of modes)\n"
 "--tense=T          Only display tense T (present, past, etc)\n"
+"                   (T can also be a comma-separated list of tenses)\n"
 "--template=T       Use template T to conjugate the verbs\n"
 "--pronouns         Include pronouns in the displayed conjugation\n"
 "--all-infinitives  Print the names of all known verbs, one per line (unsorted)\n"
+"--data-dir=D       Get XML data files from directory D instead of default\n"
+"                   directory " << LIBDATADIR << "\n"
 "\n"
 "See the " << commandName << "(1) manual page for details.\n"
 "\n"
@@ -295,13 +313,37 @@ displayHelp()
 #endif
 
 
+static vector<string>
+split(char delimiter, const char *input)
+{
+    vector<string> parts;
+    for (;;)
+    {
+        const char *foundDelim = strchr(input, delimiter);
+        if (!foundDelim)
+        {
+            if (*input)
+                parts.push_back(input);
+            return parts;
+        }
+        if (foundDelim != input)  // if part not empty
+        {
+            parts.push_back(string(input, 0, foundDelim - input));
+        }
+        input = foundDelim + 1;
+    }
+}
+
+
 int
 main(int argc, char *argv[])
 {
     setlocale(LC_CTYPE, "");
 
-    Mode reqMode = INVALID_MODE;
-    Tense reqTense = INVALID_TENSE;
+    vector<Mode> reqModes;
+    reqModes.reserve(8);
+    vector<Tense> reqTenses;
+    reqTenses.reserve(8);
     string reqTemplate;
     bool includePronouns = false;
     bool listAllInfinitives = false;
@@ -333,22 +375,45 @@ main(int argc, char *argv[])
                     break;
 
                 case 'm':
-                    reqMode = FrenchVerbDictionary::convertModeName(optarg);
-                    if (reqMode == INVALID_MODE)
+                {
+                    // Split the argument on commas, check that each mode name is valid,
+                    // accumulate modes in reqModes[].
+                    //
+                    vector<string> reqModeNames = split(',', optarg);
+                    for (vector<string>::const_iterator it = reqModeNames.begin();
+                                                       it != reqModeNames.end(); ++it)
                     {
-                        cerr << commandName << ": invalid mode " << optarg << "\n";
-                        return EXIT_FAILURE;
+                        const string &modeName = *it;
+                        Mode reqMode = FrenchVerbDictionary::convertModeName(modeName.c_str());
+                        if (reqMode == INVALID_MODE)
+                            cerr << commandName << ": invalid mode " << modeName << "\n";
+                        else
+                            reqModes.push_back(reqMode);
                     }
+                    if (reqModes.size() != reqModeNames.size())
+                        return EXIT_FAILURE;
                     break;
+                }
 
                 case 't':
-                    reqTense = FrenchVerbDictionary::convertTenseName(optarg);
-                    if (reqTense == INVALID_TENSE)
+                {
+                    // Similar to 'm'.
+                    //
+                    vector<string> reqTenseNames = split(',', optarg);
+                    for (vector<string>::const_iterator it = reqTenseNames.begin();
+                                                       it != reqTenseNames.end(); ++it)
                     {
-                        cerr << commandName << ": invalid tense " << optarg << "\n";
-                        return EXIT_FAILURE;
+                        const string &tenseName = *it;
+                        Tense reqTense = FrenchVerbDictionary::convertTenseName(tenseName.c_str());
+                        if (reqTense == INVALID_TENSE)
+                            cerr << commandName << ": invalid tense " << tenseName << "\n";
+                        else
+                            reqTenses.push_back(reqTense);
                     }
+                    if (reqTenses.size() != reqTenseNames.size())
+                        return EXIT_FAILURE;
                     break;
+                }
 
                 case 'e':
                     reqTemplate = optarg;
@@ -370,6 +435,21 @@ main(int argc, char *argv[])
                     listAllInfinitives = true;
                     break;
 
+                case 'd':
+                    if (optarg[0] == '\0')
+                    {
+                        cerr << commandName << ": invalid data directory given to --data-dir\n";
+                        return EXIT_FAILURE;
+                    }
+                    if (setenv("LIBDATADIR", optarg, true) != 0)  // for FrenchVerbDictionary::getXMLFilenames()
+                    {
+                        int e = errno;
+                        cerr << commandName << ": failed to use the data directory ("
+                             << optarg << ") given to --data-dir: " << strerror(e) << "\n";
+                        return EXIT_FAILURE;
+                    }
+                    break;
+
                 default:
                     displayHelp();
                     return EXIT_FAILURE;
@@ -402,8 +482,8 @@ main(int argc, char *argv[])
         if (listAllInfinitives)
             return cmd.listAllInfinitives(cout);
 
-        cmd.reqMode = reqMode;
-        cmd.reqTense = reqTense;
+        cmd.reqModes = reqModes;
+        cmd.reqTenses = reqTenses;
         cmd.reqTemplate = reqTemplate;
         cmd.includePronouns = includePronouns;
 
