@@ -1,4 +1,4 @@
-/*  $Id: french-deconjugator.cpp,v 1.25 2012/11/18 19:56:05 sarrazip Exp $
+/*  $Id: french-deconjugator.cpp,v 1.26 2016/11/20 04:18:08 sarrazip Exp $
     french-deconjugator.cpp - Analyzer of conjugated French verbs
 
     verbiste - French conjugation system
@@ -53,6 +53,7 @@ static struct option knownOptions[] =
     { "version",         no_argument,       NULL, 'v' },
     { "lang",            required_argument, NULL, 'l' },
     { "all-infinitives", no_argument,       NULL, 'i' },
+    { "data-dir",        required_argument, NULL, 'd' },
 
     { NULL, 0, NULL, 0 }  // marks the end
 };
@@ -139,6 +140,8 @@ displayHelp()
 "--lang=L           Select language L (fr for French, it for Italian)\n"
 "                   Default is French.\n"
 "--all-infinitives  Print the names of all known verbs, one per line (unsorted)\n"
+"--data-dir=D       Get XML data files from directory D instead of default\n"
+"                   directory " << LIBDATADIR << "\n"
 "\n"
 "See the " << commandName << "(1) manual page for details.\n"
 "\n"
@@ -188,6 +191,21 @@ main(int argc, char *argv[])
                 listAllInfinitives = true;
                 break;
 
+            case 'd':
+                if (optarg[0] == '\0')
+                {
+                    cerr << commandName << ": invalid data directory given to --data-dir\n";
+                    return EXIT_FAILURE;
+                }
+                if (setenv("LIBDATADIR", optarg, true) != 0)  // for FrenchVerbDictionary::getXMLFilenames()
+                {
+                    int e = errno;
+                    cerr << commandName << ": failed to use the data directory ("
+                         << optarg << ") given to --data-dir: " << strerror(e) << "\n";
+                    return EXIT_FAILURE;
+                }
+                break;
+
             default:
                 displayHelp();
                 return EXIT_FAILURE;
