@@ -1,8 +1,8 @@
-/*  $Id: gnome-app.cpp,v 1.14 2010/12/19 01:36:55 sarrazip Exp $
+/*  $Id: gnome-app.cpp,v 1.16 2013/05/20 21:01:30 sarrazip Exp $
     gtk-app.cpp - GTK+ application main function
 
     verbiste - French conjugation system
-    Copyright (C) 2003-2005 Pierre Sarrazin <http://sarrazip.com/>
+    Copyright (C) 2003-2013 Pierre Sarrazin <http://sarrazip.com/>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -16,8 +16,8 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-    02111-1307, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+    02110-1301, USA.
 */
 
 #include "gtk/main-window.h"
@@ -102,7 +102,19 @@ main(int argc, char *argv[])
         return EXIT_FAILURE;
     }
 
-    processText("");  // force the result window to be initially displayed
+    // Look for the first non-option argument and use it as the initial
+    // text value to process. Calling processText() here also forces
+    // the result window to be initially displayed.
+    //
+    const char *initText = "";
+    for (int i = 1; i < argc; ++i)
+        if (argv[i][0] != '-')
+        {
+            initText = argv[i];
+            break;
+        }
+    processText(initText);
+
     gtk_main();
     return EXIT_SUCCESS;
 }
