@@ -1,8 +1,8 @@
-/*  $Id: main-window.cpp,v 1.43 2013/10/29 00:58:40 sarrazip Exp $
+/*  $Id: main-window.cpp,v 1.46 2014/04/06 23:30:40 sarrazip Exp $
     main-window.cpp - Input and conjugation window
 
     verbiste - French conjugation system
-    Copyright (C) 2003-2013 Pierre Sarrazin <http://sarrazip.com/>
+    Copyright (C) 2003-2014 Pierre Sarrazin <http://sarrazip.com/>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -108,6 +108,31 @@ private:
 /*****************************************************************************/
 
 
+static GtkWidget *
+newLabel(const string &markup, gboolean selectable, gfloat yalign = 0.0)
+{
+    GtkWidget *label = gtk_label_new("");
+    gtk_label_set_markup(GTK_LABEL(label), markup.c_str());
+    gtk_misc_set_alignment(GTK_MISC(label), 0.0, yalign);
+    gtk_label_set_selectable(GTK_LABEL(label), selectable);
+    return label;
+}
+
+
+static string
+removeFirstOccurrenceOfChar(const string &original, char toRemove)
+{
+    string copy = original;
+    size_t pos = copy.find(toRemove);
+    if (pos != string::npos)  // if found
+        copy.erase(pos, 1);
+    return copy;
+}
+
+
+/*****************************************************************************/
+
+
 class ResultPage
 {
 public:
@@ -119,7 +144,9 @@ public:
 
     // No destructor because this object does not own the two GtkWidgets.
 
-    void enableLinkButton(const string &utf8Infinitive);
+    void showTemplateVerb(const string &templateVerb);
+
+    void enableLinkButton(const string &utf8Infinitive, bool isItalian);
 
 };
 
@@ -164,17 +191,35 @@ convertUTF8ToPercentHex(const char *utf8)
 }
 
 
+// Shows the verb that serves as the template for the displayed conjugation.
+//
+void
+ResultPage::showTemplateVerb(const string &templateVerb)
+{
+    GtkWidget *cell = newLabel(_("Model:") + (" " + templateVerb), TRUE);
+    gtk_table_attach(GTK_TABLE(table), cell,
+                            1, 2, 0, 1,
+                            GTK_FILL, GTK_SHRINK,
+                            8, 8);
+}
+
+
 // Adds a link to the table that points to a web page that defines the verb.
 //
 void
-ResultPage::enableLinkButton(const string &utf8Infinitive)
+ResultPage::enableLinkButton(const string &utf8Infinitive, bool isItalian)
 {
-    string uri = "http://fr.wiktionary.org/wiki/"
+    string uri = "http://" + string(isItalian ? "it" : "fr")
+                    + ".wiktionary.org/wiki/"
                     + convertUTF8ToPercentHex(utf8Infinitive.c_str());
     GtkWidget *linkButton = gtk_link_button_new_with_label(
-                                uri.c_str(), _("Look up on Wiktionnaire"));
+                                uri.c_str(),
+                                isItalian
+                                    ?  _("Look up on Wikizionario")
+                                    :  _("Look up on Wiktionnaire")
+                                );
     gtk_table_attach(GTK_TABLE(table), linkButton,
-                        1, 3, 0, 1,
+                        2, 3, 0, 1,
                         GTK_SHRINK, GTK_SHRINK,
                         8, 8);
 }
@@ -309,7 +354,7 @@ showAbout()
     }
 
     if (logo != NULL)
-        gdk_pixbuf_unref(logo);
+        g_object_unref(logo);
 
     g_signal_connect(G_OBJECT(about), "key-press-event",
                         G_CALLBACK(onKeyPressInAbout), NULL);
@@ -768,18 +813,6 @@ onSaveAsButton(GtkWidget *, gpointer)
 }
 
 
-static
-GtkWidget *
-newLabel(const string &markup, gboolean selectable, gfloat yalign = 0.0)
-{
-    GtkWidget *label = gtk_label_new("");
-    gtk_label_set_markup(GTK_LABEL(label), markup.c_str());
-    gtk_misc_set_alignment(GTK_MISC(label), 0.0, yalign);
-    gtk_label_set_selectable(GTK_LABEL(label), selectable);
-    return label;
-}
-
-
 static
 ResultPage *
 appendResultPage(const string &utf8LabelText)
@@ -1286,7 +1319,9 @@ deconjugate(FrenchVerbDictionary &fvd, const string &utf8UserText,
         string label = utf8Infinitive + " (" + FrenchVerbDictionary::getLanguageCode(fvd.getLanguage()) + ")";
         ResultPage *rp = appendResultPage(label);
 
-        rp->enableLinkButton(utf8Infinitive);
+        rp->showTemplateVerb(removeFirstOccurrenceOfChar(d.templateName, ':'));
+
+        rp->enableLinkButton(utf8Infinitive, isItalian);
 
         numPages++;
 
