@@ -1,4 +1,4 @@
-/*  $Id: FrenchVerbDictionary.cpp,v 1.55 2015/09/26 19:30:17 sarrazip Exp $
+/*  $Id: FrenchVerbDictionary.cpp,v 1.56 2016/11/20 07:26:34 sarrazip Exp $
     FrenchVerbDictionary.cpp - Dictionary of verbs and conjugation templates
 
     verbiste - French conjugation system
@@ -759,7 +759,6 @@ FrenchVerbDictionary::convertModeName(const char *modeName)
     if (mode == INVALID_MODE)
     {
         if (trace) cout << "modeName='" << modeName << "'" << endl;
-        assert(!"Invalid mode");
     }
 
     return mode;
@@ -807,7 +806,6 @@ FrenchVerbDictionary::convertTenseName(const char *tenseName)
     if (tense == INVALID_TENSE)
     {
         if (trace) cout << "tenseName='" << tenseName << "'" << endl;
-        assert(!"Invalid tense");
     }
 
     return tense;
